% solution of examples No. 1 to 3 - non-stationary problems
   clc

   % vector (array) of nodal coordinates
    x = [0.0 0.1 0.2 0.3];

   % vector (array) of element conductivities
    lam = [2.0 2.0 2.0];

   % vector (array) of element volume weight
   ro = [2500.0 2500.0 2500.0];

   % vector (array) of element specific heat
   cp = [1000.0 1000.0 1000.0];

   % conectivity
    con = [1 2;
          2 3;
          3 4];

   % vector (array) of nodal code numbers
    cn = [0 1 2 0];

    % vector (array) of nodal Dirichlet b.c.
    d = [5.0 0 0 20.0];

    % vector (array) of nodal Neumann b.c.
    fn = [0 0 0 0];

    % vector (array) of nodal Newton b.c.
    fc = [0 0 0 0];

    % vector (array) of nodal transfer coefficients
    alpha = [0.0 0.0 0.0 0];

    % number of unknowns (DOF)
    n = 2;

    % number of nodes
    nn = 4;

    % number of elements
    nel = 3;

    k = zeros(n,n);
    c = zeros(n,n); % global capacity matrix
    xe = zeros(2,1);
    ke = zeros(2,2);
    ce = zeros(2,2); % element capacity matrix
    de = zeros(2,1);
    ne = zeros(2,1);
    newe = zeros(2,1);
    f = zeros(n,1);

    for i=1:nel
        ia = con(i,1);
        ib = con(i,2);

        xe(1) = x(ia);
        xe(2) = x(ib);

        ke = conductivity_matrix (xe,lam(i));
        % element capacity matrix
        ce = capacity_matrix (xe,ro(i),cp(i));

        cne(1) = cn(ia);
        cne(2) = cn(ib);
        de(1) = d(ia);
        de(2) = d(ib);
        ne(1) = fn(ia);
        ne(2) = fn(ib);
        newe(1) = fc(ia)*alpha(ia);
        newe(2) = fc(ib)*alpha(ib);

        % conductivity matrix assembly
        k = localization(k, ke, cne);
        % capacity matrix assembly
        c = localization(c, ce, cne);

        % right hand side
        f = right_hand_side_dirichlet (f, ke, de, cne);
        f = right_hand_side_neumann (f, ne, cne);
        f = right_hand_side_newton (f, newe, cne);

        % contribution from Newton b.c.
        alpha_e(1) = alpha(ia);
        alpha_e(2) = alpha(ib);
        ke = conductivity_matrix_newton (alpha_e);
        % localization - conductivity matrix assembly
        k = localization(k, ke, cne);
    end
   k
   c
   f

   % time integration
   % initial conditions
   t_init = [2.0 2.0 2.0 2.0];

   % initial time
   t_start = 0.0;

   % end time
   t_end = 100000.0;

   % time step
   delta_t = 1000.0;

   % tau parameter
   tau = 0.5;

   % T_i-1
   r_old = zeros(n,1);

   %T_i
   r_new = zeros(n,1);

   % initial temperatures localization
    for i=1:nn
        if (cn(i) ~= 0)
            r_old(cn(i)) = t_init(i);
        end
    end

    t = t_start;
    out = fopen('nonstat_res.dat','w');
    j = 0;

    while t ~= t_end
        % system of equations matrix
        a = (k*tau + c/delta_t);

        % right-hand side vector
        rhs = f*(1.0 - tau) + f*tau + (c/delta_t - k*(1.0 - tau))*r_old;

        % solution
        r_new = a\rhs;

        % print into file
        fprintf(out,'%f',t);
        for i=1:n
          fprintf(out,'  %f',r_new(i));
        end
        fprintf(out,'\n');

        % print into a graph for the first unknown temperature
        j = j + 1;
        time(j) = t;
        temperature(j) = r_new(2);

        % actualization
        r_old = r_new;
        t = t + delta_t;
    end

    fclose(out);
    plot (time,temperature);
    r_new



